@@ -1,5 +1,5 @@
 package App::Wallflower;
-$App::Wallflower::VERSION = '1.014';
+$App::Wallflower::VERSION = '1.015';
 use strict;
 use warnings;
 
@@ -30,7 +30,15 @@ my @callbacks = (
             my ( $url, $response ) = @_;
             my ( $status, $headers, $file ) = @$response;
             return if $status == 200;
-            printf "$status %s\n", $url->path;
+            if ( $status == 301 ) {
+                my $i = 0;
+                $i += 2
+                  while $i < @$headers && lc( $headers->[$i] ) ne 'location';
+                printf "$status %s -> %s\n", $url->path, $headers->[ $i + 1 ] || '?';
+            }
+            else {
+                printf "$status %s\n", $url->path;
+            }
         },
     ],
     [
@@ -235,7 +243,7 @@ sub _aggregate_todo {
 
     # aggregate all child todo into ours and save it as __TODO__
     local *ARGV;
-    @ARGV = glob $self->{_ipc_dir_}->child('todo-*');
+    @ARGV = ( $TODO, glob $self->{_ipc_dir_}->child('todo-*') );
     no warnings 'inplace';    # some files may already be gone
     my $fh = File::Temp->new(
         TEMPLATE => "__TODO__-XXXX",
@@ -452,7 +460,7 @@ App::Wallflower - Class performing the moves for the wallflower program
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 SYNOPSIS
 
